@@ -596,13 +596,6 @@ class ErrorQuarkFunction(Function):
         self.error_domain = error_domain
 
 
-class ErrorQuarkFunction(Function):
-
-    def __init__(self, name, retval, parameters, throws, symbol, error_domain):
-        Function.__init__(self, name, retval, parameters, throws, symbol)
-        self.error_domain = error_domain
-
-
 class VFunction(Callable):
 
     def __init__(self, name, retval, parameters, throws):
@@ -993,10 +986,11 @@ class Interface(Node, Registered):
 
 class Constant(Node):
 
-    def __init__(self, name, value_type, value):
+    def __init__(self, name, value_type, value, ctype):
         Node.__init__(self, name)
         self.value_type = value_type
         self.value = value
+        self.ctype = ctype
 
 
 class Property(Node):
