@@ -395,6 +395,7 @@ void gi_marshalling_tests_array_inout_etc (gint first, gint **ints, gint *length
 /* Zero-terminated */
 
 gchar **gi_marshalling_tests_array_zero_terminated_return (void);
+gchar **gi_marshalling_tests_array_zero_terminated_return_null (void);
 GIMarshallingTestsBoxedStruct **gi_marshalling_tests_array_zero_terminated_return_struct (void);
 
 void gi_marshalling_tests_array_zero_terminated_in (gchar **utf8s);
@@ -526,6 +527,14 @@ void gi_marshalling_tests_gvalue_out (GValue **value);
 
 void gi_marshalling_tests_gvalue_inout (GValue **value);
 
+void gi_marshalling_tests_gvalue_flat_array (guint         n_values,
+                                             const GValue *values);
+
+GValue *gi_marshalling_tests_return_gvalue_flat_array (void);
+
+GValue *gi_marshalling_tests_gvalue_flat_array_round_trip (const GValue one,
+                                                           const GValue two,
+                                                           const GValue three);
 
 /* GClosure */
 
