@@ -811,3 +811,25 @@ void
 annotation_space_after_comment_bug631690 (void)
 {
 }
+
+/**
+ * annotation_return_filename:
+ *
+ * Returns: (type filename): An annotated filename
+ */
+gchar*
+annotation_return_filename (void)
+{
+  return "a utf-8 filename";
+}
+
+/**
+ * annotation_transfer_floating:
+ *
+ * Returns: (transfer floating): A floating object
+ */
+GObject *
+annotation_transfer_floating(void)
+{
+  return NULL;
+}
